@@ -1,10 +1,10 @@
 /*
  * astime is an analogue clock utility for X Windows.
  *
- * Copyright (c) 1998-99  Albert Dorofeev <Albert@mail.dma.be>
+ * Copyright (c) 1998-2000  Albert Dorofeev <albert@tigr.net>
  * Copyright (c) 1999 William Kostis <kostis@ee.cornell.edu>
  *
- * For the updates see http://bewoner.dma.be/Albert/afterstep/
+ * For the updates see http://www.tigr.net/afterstep/as-apps/
  *
  * This software is distributed under GPL. For details see LICENSE file.
  */
@@ -112,8 +112,8 @@ void defaults()
 	safecopy(state.program_name, "echo astime: No program specified.", 255);
 
 	state.nprogs = 0;
-	/* state.PI = (PInfo *) malloc(sizeof(*(state.PI))); */
-	state.PI = (PInfo *) NULL;
+	/* state.PInf = (PInfo *) malloc(sizeof(*(state.PInf))); */
+	state.PInf = (PInfo *) NULL;
 }
 
 /* print the usage for the tool */
@@ -163,7 +163,7 @@ void usage()
 /* print the version of the tool */
 void version()
 {
-	printf("astime : AfterStep analog clock version 2.5\n");
+	printf("astime : AfterStep analog clock version 2.6\n");
 }
 
 /* parse the rc file */
@@ -327,13 +327,13 @@ void parsercfile(FILE * ifp)
 			} else if (!strcmp(param[0], "at")) {
 				ind = state.nprogs;
 				state.nprogs += 1;
-				state.PI = (PInfo *) realloc(state.PI, state.nprogs * sizeof(*(state.PI)));
-				if (state.PI == NULL) {
+				state.PInf = (PInfo *) realloc(state.PInf, state.nprogs * sizeof(*(state.PInf)));
+				if (state.PInf == NULL) {
 					fprintf(stderr, "astime: memory reallocation error, exiting\n");
 					exit(1);
 				}
-				state.PI[ind] = (PInfo) malloc(sizeof(**(state.PI)));
-				if (state.PI[ind] == NULL) {
+				state.PInf[ind] = (PInfo) malloc(sizeof(**(state.PInf)));
+				if (state.PInf[ind] == NULL) {
 					fprintf(stderr, "astime: memory reallocation error, exiting\n");
 					exit(1);
 				}
@@ -341,9 +341,9 @@ void parsercfile(FILE * ifp)
 					wptr = strtok(NULL, " :");
 					tval = atoi(wptr);
 #ifdef DEBUG
-					fprintf(stderr, "map (state.PI[%d]->time[%d]) <- %d <%s>\n", ind, j, tval, wptr);
+					fprintf(stderr, "map (state.PInf[%d]->time[%d]) <- %d <%s>\n", ind, j, tval, wptr);
 #endif
-					state.PI[ind]->time[j] = tval;
+					state.PInf[ind]->time[j] = tval;
 				}
 
 				wptr += 3;
@@ -351,13 +351,13 @@ void parsercfile(FILE * ifp)
 
 				if (eptr != NULL) {
 					eptr += 1;
-					safecopy(state.PI[ind]->name, eptr, strlen(eptr) - 1);
-					state.PI[ind]->done = 0;
+					safecopy(state.PInf[ind]->name, eptr, strlen(eptr) - 1);
+					state.PInf[ind]->done = 0;
 					state.cron_program = 1;
 #ifdef P_CRON
 					fprintf(stderr, "cron[%d] : %02d:%02d:%02d : <%s>\n",
-						ind, state.PI[ind]->time[0], state.PI[ind]->time[1],
-						state.PI[ind]->time[2], state.PI[ind]->name);
+						ind, state.PInf[ind]->time[0], state.PInf[ind]->time[1],
+						state.PInf[ind]->time[2], state.PInf[ind]->name);
 #endif
 				} else
 					fprintf(stderr, "astime: executables must be double-quoted in astimerc file, ignoring...\n");
