@@ -1,10 +1,10 @@
 /*
  * astime is an analogue clock utility for X Windows.
  *
- * Copyright (c) 1998-99  Albert Dorofeev <Albert@mail.dma.be>
+ * Copyright (c) 1998-2000  Albert Dorofeev <albert@tigr.net>
  * Copyright (c) 1999 William Kostis <kostis@ee.cornell.edu>
  *
- * For the updates see http://bewoner.dma.be/Albert/afterstep/
+ * For the updates see http://www.tigr.net/afterstep/as-apps/
  *
  * This software is distributed under GPL. For details see LICENSE file.
  */
@@ -95,7 +95,7 @@ struct tm *loc_time;
 /* requests for update */
 int update_request = 0;
 
-float pi = 3.14159265359;
+/* float pi = 3.14159265359; */
 
 void draw_window(Window win)
 {
@@ -333,11 +333,11 @@ void draw_window(Window win)
 /* convert the position on 0-60 scale into xy coordinates */
 inline float convert2x(int tim)
 {
-	return cos(pi * (((float) (tim - 15)) * 6) / 180);
+	return cos(M_PI * (((float) (tim - 15)) * 6) / 180);
 }
 inline float convert2y(int tim)
 {
-	return sin(pi * (((float) (tim - 15)) * 6) / 180);
+	return sin(M_PI * (((float) (tim - 15)) * 6) / 180);
 }
 
 float hwidth[3];
@@ -511,15 +511,15 @@ void croncheck()
 	int i;
 
 	for (i = 0; i < state.nprogs; i++) {
-		if (loc_time->tm_hour == state.PI[i]->time[0]) {
-			if (loc_time->tm_min == state.PI[i]->time[1]) {
-				if ((loc_time->tm_sec == state.PI[i]->time[2])) {
-					if (!state.PI[i]->done) {
-						state.PI[i]->done = 1;
-						system(state.PI[i]->name);
+		if (loc_time->tm_hour == state.PInf[i]->time[0]) {
+			if (loc_time->tm_min == state.PInf[i]->time[1]) {
+				if ((loc_time->tm_sec == state.PInf[i]->time[2])) {
+					if (!state.PInf[i]->done) {
+						state.PInf[i]->done = 1;
+						system(state.PInf[i]->name);
 					}
 				} else {
-					state.PI[i]->done = 0;
+					state.PInf[i]->done = 0;
 				}
 			}
 		}
